@@ -1,19 +1,19 @@
 ## File Name: BIFIE.bifiedata2bifiecdata.R
-## File Version: 2.19
+## File Version: 2.22
 
-#######################################################
-# conversion of BIFIEdata to BIFIEcdata
+
+#--- conversion of BIFIEdata to BIFIEcdata
 BIFIE.BIFIEdata2BIFIEcdata <- function( bifieobj, varnames=NULL, impdata.index=NULL )
 {
     if ( bifieobj$cdata ){
         stop( "You may want to use 'BIFIE.BIFIEcdata2BIFIEdata'\n")
     }
-    #******** select some imputed datasets or some variables
+    #*** select some imputed datasets or some variables
     bifieobj <- BIFIE.data.select( bifieobj=bifieobj, varnames=varnames,
                     impdata.index=impdata.index )
-
-    #**** data conversion
-    res1 <- bifiesurvey_rcpp_bifiedata2bifiecdata( datalistM=bifieobj$datalistM, Nimp=bifieobj$Nimp )
+    #*** data conversion
+    res1 <- bifiesurvey_rcpp_bifiedata2bifiecdata( datalistM=bifieobj$datalistM,
+                        Nimp=bifieobj$Nimp )
     bifieobj$cdata <- TRUE
     bifieobj$datalistM <- NULL
     bifieobj$datalistM_ind <- res1$datalistM_ind
@@ -23,4 +23,3 @@ BIFIE.BIFIEdata2BIFIEcdata <- function( bifieobj, varnames=NULL, impdata.index=N
     bifieobj$time <- Sys.time()
     return(bifieobj)
 }
-#######################################################
