@@ -1,5 +1,5 @@
 //// File Name: bifiesurvey_rcpp_main.cpp
-//// File Version: 7.945
+//// File Version: 7.946
 
 
 #include <RcppArmadillo.h>
@@ -1178,144 +1178,6 @@ Rcpp::List bifie_ecdf( Rcpp::NumericMatrix datalist, Rcpp::NumericMatrix wgt1,
 }
 //*************************************************************************
 
-//*************************************************************************
-//  bifie_logistreg
-// [[Rcpp::export]]
-Rcpp::List bifie_logistreg( Rcpp::NumericMatrix datalist, Rcpp::NumericMatrix wgt1,
-    Rcpp::NumericMatrix wgtrep, Rcpp::NumericVector dep_index,
-    Rcpp::NumericVector pre_index, Rcpp::NumericVector fayfac,
-    Rcpp::NumericVector NI, Rcpp::NumericVector group_index1,
-    Rcpp::NumericVector group_values, double eps, int maxiter ){
-
-     int Nimp = NI[0];
-     int RR = wgtrep.ncol();
-     int N = wgt1.nrow();
-     int VV = pre_index.size();
-     int NV = datalist.ncol();
-     int group_index = group_index1[0];
-     int GG=group_values.size();
-
-     Rcpp::NumericMatrix dat1(N,NV);
-     Rcpp::NumericVector tempvec(N);
-     int uu=0;
-
-     int VV2=VV*GG;
-     Rcpp::NumericMatrix ncasesM(GG,Nimp);
-     Rcpp::NumericMatrix sumwgtM(GG,Nimp);
-     Rcpp::NumericMatrix regrcoefM(VV2,Nimp);
-     Rcpp::NumericMatrix regrcoef_varM(VV2,Nimp);
-     int WW = wgtrep.ncol();
-     Rcpp::NumericMatrix regrcoefrepM(VV2,Nimp*WW);
-     Rcpp::NumericMatrix tempcoefrepM(VV2,WW);
-     Rcpp::NumericVector regrcoef0(VV2);
-     Rcpp::NumericVector beta0(VV);
-     Rcpp::Rcout << "|";
-
-     // loop over imputed datasets
-     for ( int ii=0; ii < Nimp; ii ++ ){
-     // extract dataset
-     dat1 = datalist( Rcpp::Range( ii*N+0, ii*N+ (N-1) ), Rcpp::Range(0,NV-1) );
-
-     // loop over group values gg
-     int ind=1;
-     for (int gg=0; gg < GG; gg ++ ){
-     uu=0;
-     for (int nn=0;nn<N;nn++){
-     ind = 1;
-     if ( dat1(nn,group_index) == group_values[gg] ){
-
-         if ( R_IsNA( dat1(nn,dep_index[0] ) ) ){
-                 ind = 0;
-                     }  // end NA dep
-         for (int vv=0;vv<VV;vv++){
-            if ( R_IsNA( dat1(nn,pre_index[vv] ) ) ){
-                 ind = 0;
-                     }  // end NA dep
-         }
-         if ( ind > 0 ){
-         ncasesM(gg,ii) ++;
-         sumwgtM(gg,ii) += wgt1[nn];
-         tempvec[uu] = nn;
-         uu ++;
-             }
-                 } // end group_val == gg
-          }
-
-     // create datasets for logistic regression
-     int ngg=ncasesM(gg,ii);
-     Rcpp::NumericMatrix Xt(ngg,VV);
-     Rcpp::NumericVector yt(ngg);
-     Rcpp::NumericVector wgtt(ngg);
-     Rcpp::NumericMatrix wgtrept(ngg,RR);
-     Rcpp::NumericVector wgttemp(ngg);
-
-     for (int tt=0;tt<ngg;tt++){
-         yt[tt] = dat1( tempvec[tt], dep_index[0] );
-         wgtt[tt] = wgt1[ tempvec[tt] ];
-         for (int rr=0;rr<RR;rr++){
-             wgtrept(tt,rr) = wgtrep( tempvec[tt],rr);
-                     }
-         for (int vv=0;vv<VV;vv++){
-             Xt(tt,vv)=dat1( tempvec[tt], pre_index[vv] );
-                     }
-                 } // end cases tt
-     // logistic regression original dataset
-     Rcpp::List res1 = bifie_estlogistic_helper(  yt,
-         Xt, wgtt, beta0, eps, maxiter );
-     Rcpp::NumericVector tempcoef=res1["beta"];
-     for (int vv=0;vv<VV;vv++){
-         regrcoefM(vv+gg*VV,ii) = tempcoef[vv];
-             }
-
-     Rcpp::List res2;
-     // replicated datasets
-     // tempcoefrepM
-     for (int rr=0;rr<RR;rr++){
-     for (int tt=0;tt<ngg;tt++){
-         wgttemp[tt] = wgtrept(tt,rr);
-                 }
-     res2 = bifie_estlogistic_helper(  yt,    Xt,
-         wgttemp, tempcoef, eps, maxiter );
-     Rcpp::NumericVector tempcoef2=res2["beta"];
-     for (int vv=0;vv<VV;vv++){
-         tempcoefrepM(vv+gg*VV,rr) = tempcoef2[vv];
-             }
-     } // end rr
-     } // end gg
-
-     for (int zz=0;zz<VV2;zz++){
-        regrcoef0[zz] = regrcoefM(zz,ii);
-            }
-
-     // compute standard errors
-     Rcpp::NumericVector regrcoef_var = varjack_helper(
-             regrcoef0, tempcoefrepM, fayfac );
-
-     for (int zz=0;zz<VV2; zz++){
-     //    regrcoefM(zz,ii) = regrcoef0[zz];
-         regrcoef_varM(zz,ii) = regrcoef_var[zz];
-         for (int ww=0;ww<WW;ww++){
-                regrcoefrepM(zz, ww + ii*WW ) = tempcoefrepM(zz,ww);
-                        }
-     }
-        Rcpp::Rcout << "-" <<  std::flush;
-          }  // end ii;  end multiple imputations
-     Rcpp::Rcout << "|" << std::endl;
-     ///*** Rubin inference
-     Rcpp::List regrcoefL = rubin_rules_univ( regrcoefM, regrcoef_varM );
-     //*************************************************
-     // OUTPUT
-     return Rcpp::List::create(
-         Rcpp::_["ncasesM"] = ncasesM,
-         Rcpp::_["sumwgtM"] = sumwgtM,
-         Rcpp::_["regrcoefrepM"] = regrcoefrepM,
-         Rcpp::_["regrcoefL"] = regrcoefL,
-         Rcpp::_["regrcoefM"] = regrcoefM,
-         Rcpp::_["regrcoef_varM"] = regrcoef_varM
-         );
-}
-
-//*************************************************************************
 
 //*************************************************************************
 //  bifie_fasttable
